@@ -170,11 +170,32 @@ func TestApp_List(t *testing.T) {
 		},
 		{
 			name: "list codespaces,--web",
+			fields: fields{
+				apiClient: &apiClientMock{
+					ServerURLFunc: func() string {
+						return "https://github.com"
+					},
+				},
+			},
 			opts: &listOptions{
 				useWeb: true,
 			},
 			wantURL: "https://github.com/codespaces",
 		},
+		{
+			name: "list codespaces,--web with custom server url",
+			fields: fields{
+				apiClient: &apiClientMock{
+					ServerURLFunc: func() string {
+						return "https://github.mycompany.com"
+					},
+				},
+			},
+			opts: &listOptions{
+				useWeb: true,
+			},
+			wantURL: "https://github.mycompany.com/codespaces",
+		},
 		{
 			name: "list codespaces,--web, --repo flag",
 			fields: fields{
@@ -199,6 +220,9 @@ func TestApp_List(t *testing.T) {
 							},
 						}, nil
 					},
+					ServerURLFunc: func() string {
+						return "https://github.com"
+					},
 				},
 			},
 			opts: &listOptions{
