@@ -19,13 +19,16 @@ import (
 	"github.com/cli/cli/v2/pkg/cmd/repo/shared"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/iostreams"
-	"github.com/cli/cli/v2/pkg/prompt"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
 )
 
 const defaultRemoteName = "origin"
 
+type iprompter interface {
+	Confirm(string, bool) (bool, error)
+}
+
 type ForkOptions struct {
 	HttpClient func() (*http.Client, error)
 	GitClient  *git.Client
@@ -35,6 +38,7 @@ type ForkOptions struct {
 	Remotes    func() (ghContext.Remotes, error)
 	Since      func(time.Time) time.Duration
 	BackOff    backoff.BackOff
+	Prompter   iprompter
 
 	GitArgs           []string
 	Repository        string
@@ -65,6 +69,7 @@ func NewCmdFork(f *cmdutil.Factory, runF func(*ForkOptions) error) *cobra.Comman
 		Config:     f.Config,
 		BaseRepo:   f.BaseRepo,
 		Remotes:    f.Remotes,
+		Prompter:   f.Prompter,
 		Since:      time.Since,
 	}
 
@@ -273,10 +278,9 @@ func forkRun(opts *ForkOptions) error {
 
 		remoteDesired := opts.Remote
 		if opts.PromptRemote {
-			//nolint:staticcheck // SA1019: prompt.Confirm is deprecated: use Prompter
-			err = prompt.Confirm("Would you like to add a remote for the fork?", &remoteDesired)
+			remoteDesired, err = opts.Prompter.Confirm("Would you like to add a remote for the fork?", false)
 			if err != nil {
-				return fmt.Errorf("failed to prompt: %w", err)
+				return err
 			}
 		}
 
@@ -317,10 +321,9 @@ func forkRun(opts *ForkOptions) error {
 	} else {
 		cloneDesired := opts.Clone
 		if opts.PromptClone {
-			//nolint:staticcheck // SA1019: prompt.Confirm is deprecated: use Prompter
-			err = prompt.Confirm("Would you like to clone the fork?", &cloneDesired)
+			cloneDesired, err = opts.Prompter.Confirm("Would you like to clone the fork?", false)
 			if err != nil {
-				return fmt.Errorf("failed to prompt: %w", err)
+				return err
 			}
 		}
 		if cloneDesired {
