@@ -38,7 +38,7 @@ func TestNewCmdList(t *testing.T) {
 				Fork:        false,
 				Source:      false,
 				Language:    "",
-				Topic:       "",
+				Topic:       []string(nil),
 				Archived:    false,
 				NonArchived: false,
 			},
@@ -53,7 +53,7 @@ func TestNewCmdList(t *testing.T) {
 				Fork:        false,
 				Source:      false,
 				Language:    "",
-				Topic:       "",
+				Topic:       []string(nil),
 				Archived:    false,
 				NonArchived: false,
 			},
@@ -68,7 +68,7 @@ func TestNewCmdList(t *testing.T) {
 				Fork:        false,
 				Source:      false,
 				Language:    "",
-				Topic:       "",
+				Topic:       []string(nil),
 				Archived:    false,
 				NonArchived: false,
 			},
@@ -83,7 +83,7 @@ func TestNewCmdList(t *testing.T) {
 				Fork:        false,
 				Source:      false,
 				Language:    "",
-				Topic:       "",
+				Topic:       []string(nil),
 				Archived:    false,
 				NonArchived: false,
 			},
@@ -98,7 +98,7 @@ func TestNewCmdList(t *testing.T) {
 				Fork:        false,
 				Source:      false,
 				Language:    "",
-				Topic:       "",
+				Topic:       []string(nil),
 				Archived:    false,
 				NonArchived: false,
 			},
@@ -113,7 +113,7 @@ func TestNewCmdList(t *testing.T) {
 				Fork:        true,
 				Source:      false,
 				Language:    "",
-				Topic:       "",
+				Topic:       []string(nil),
 				Archived:    false,
 				NonArchived: false,
 			},
@@ -128,7 +128,7 @@ func TestNewCmdList(t *testing.T) {
 				Fork:        false,
 				Source:      true,
 				Language:    "",
-				Topic:       "",
+				Topic:       []string(nil),
 				Archived:    false,
 				NonArchived: false,
 			},
@@ -143,7 +143,7 @@ func TestNewCmdList(t *testing.T) {
 				Fork:        false,
 				Source:      false,
 				Language:    "go",
-				Topic:       "",
+				Topic:       []string(nil),
 				Archived:    false,
 				NonArchived: false,
 			},
@@ -158,7 +158,7 @@ func TestNewCmdList(t *testing.T) {
 				Fork:        false,
 				Source:      false,
 				Language:    "",
-				Topic:       "",
+				Topic:       []string(nil),
 				Archived:    true,
 				NonArchived: false,
 			},
@@ -173,7 +173,7 @@ func TestNewCmdList(t *testing.T) {
 				Fork:        false,
 				Source:      false,
 				Language:    "",
-				Topic:       "",
+				Topic:       []string(nil),
 				Archived:    false,
 				NonArchived: true,
 			},
@@ -188,7 +188,22 @@ func TestNewCmdList(t *testing.T) {
 				Fork:        false,
 				Source:      false,
 				Language:    "",
-				Topic:       "cli",
+				Topic:       []string{"cli"},
+				Archived:    false,
+				NonArchived: false,
+			},
+		},
+		{
+			name: "with multiple topic",
+			cli:  "--topic cli --topic multiple-topic",
+			wants: ListOptions{
+				Limit:       30,
+				Owner:       "",
+				Visibility:  "",
+				Fork:        false,
+				Source:      false,
+				Language:    "",
+				Topic:       []string{"cli", "multiple-topic"},
 				Archived:    false,
 				NonArchived: false,
 			},
@@ -421,7 +436,7 @@ func TestRepoList_noVisibilityField(t *testing.T) {
 			return &http.Client{Transport: reg}, nil
 		},
 		Config: func() (config.Config, error) {
-			return config.InheritEnv(config.NewBlankConfig()), nil
+			return config.NewBlankConfig(), nil
 		},
 		Now: func() time.Time {
 			t, _ := time.Parse(time.RFC822, "19 Feb 21 15:00 UTC")
@@ -437,3 +452,40 @@ func TestRepoList_noVisibilityField(t *testing.T) {
 	assert.Equal(t, "", stderr.String())
 	assert.Equal(t, "", stdout.String())
 }
+
+func TestRepoList_invalidOwner(t *testing.T) {
+	ios, _, stdout, stderr := iostreams.Test()
+	ios.SetStdoutTTY(false)
+	ios.SetStdinTTY(false)
+	ios.SetStderrTTY(false)
+
+	reg := &httpmock.Registry{}
+	defer reg.Verify(t)
+
+	reg.Register(
+		httpmock.GraphQL(`query RepositoryList\b`),
+		httpmock.StringResponse(`{ "data": { "repositoryOwner": null } }`),
+	)
+
+	opts := ListOptions{
+		Owner: "nonexist",
+		IO:    ios,
+		HttpClient: func() (*http.Client, error) {
+			return &http.Client{Transport: reg}, nil
+		},
+		Config: func() (config.Config, error) {
+			return config.NewBlankConfig(), nil
+		},
+		Now: func() time.Time {
+			t, _ := time.Parse(time.RFC822, "19 Feb 21 15:00 UTC")
+			return t
+		},
+		Limit:    30,
+		Detector: &fd.DisabledDetectorMock{},
+	}
+
+	err := listRun(&opts)
+	assert.EqualError(t, err, `the owner handle "nonexist" was not recognized as either a GitHub user or an organization`)
+	assert.Equal(t, "", stderr.String())
+	assert.Equal(t, "", stdout.String())
+}
