@@ -11,11 +11,9 @@ import (
 	"strconv"
 	"strings"
 
-	"github.com/AlecAivazis/survey/v2"
 	"github.com/cli/cli/v2/api"
 	"github.com/cli/cli/v2/internal/ghrepo"
 	"github.com/cli/cli/v2/pkg/iostreams"
-	"github.com/cli/cli/v2/pkg/prompt"
 	"github.com/cli/go-gh/v2/pkg/asciisanitizer"
 	"golang.org/x/text/transform"
 )
@@ -26,6 +24,10 @@ const (
 	DisabledInactivity WorkflowState = "disabled_inactivity"
 )
 
+type iprompter interface {
+	Select(string, string, []string) (int, error)
+}
+
 type WorkflowState string
 
 type Workflow struct {
@@ -90,7 +92,7 @@ type FilteredAllError struct {
 	error
 }
 
-func SelectWorkflow(workflows []Workflow, promptMsg string, states []WorkflowState) (*Workflow, error) {
+func selectWorkflow(p iprompter, workflows []Workflow, promptMsg string, states []WorkflowState) (*Workflow, error) {
 	filtered := []Workflow{}
 	candidates := []string{}
 	for _, workflow := range workflows {
@@ -107,14 +109,7 @@ func SelectWorkflow(workflows []Workflow, promptMsg string, states []WorkflowSta
 		return nil, FilteredAllError{errors.New("")}
 	}
 
-	var selected int
-
-	//nolint:staticcheck // SA1019: prompt.SurveyAskOne is deprecated: use Prompter
-	err := prompt.SurveyAskOne(&survey.Select{
-		Message:  promptMsg,
-		Options:  candidates,
-		PageSize: 15,
-	}, &selected)
+	selected, err := p.Select(promptMsg, "", candidates)
 	if err != nil {
 		return nil, err
 	}
@@ -182,7 +177,7 @@ func getWorkflowsByName(client *api.Client, repo ghrepo.Interface, name string,
 	return filtered, nil
 }
 
-func ResolveWorkflow(io *iostreams.IOStreams, client *api.Client, repo ghrepo.Interface, prompt bool, workflowSelector string, states []WorkflowState) (*Workflow, error) {
+func ResolveWorkflow(p iprompter, io *iostreams.IOStreams, client *api.Client, repo ghrepo.Interface, prompt bool, workflowSelector string, states []WorkflowState) (*Workflow, error) {
 	if prompt {
 		workflows, err := GetWorkflows(client, repo, 0)
 		if len(workflows) == 0 {
@@ -198,7 +193,7 @@ func ResolveWorkflow(io *iostreams.IOStreams, client *api.Client, repo ghrepo.In
 			return nil, fmt.Errorf("could not fetch workflows for %s: %w", ghrepo.FullName(repo), err)
 		}
 
-		return SelectWorkflow(workflows, "Select a workflow", states)
+		return selectWorkflow(p, workflows, "Select a workflow", states)
 	}
 
 	workflows, err := FindWorkflow(client, repo, workflowSelector, states)
@@ -222,7 +217,7 @@ func ResolveWorkflow(io *iostreams.IOStreams, client *api.Client, repo ghrepo.In
 		return nil, errors.New(errMsg)
 	}
 
-	return SelectWorkflow(workflows, "Which workflow do you mean?", states)
+	return selectWorkflow(p, workflows, "Which workflow do you mean?", states)
 }
 
 func GetWorkflowContent(client *api.Client, repo ghrepo.Interface, workflow Workflow, ref string) ([]byte, error) {
